@@ -35,7 +35,7 @@ def fileserver(base_dir: str = '../../data/warc', port: int = 8866):
 
 
 @app.command()
-def bulk_perplexity(perpl_model: str = '../../trec-pipeline-2021/nlp-improvements/perplexity/models/bigrams_cord19.st',
+def bulk_perplexity(model: str = 'bigrams-bnc',
                     perpl_limit: float = 2000.0,
                     base_dir: str = '../data/warc',
                     output_dir: str = '../data/warc_out',
@@ -44,7 +44,7 @@ def bulk_perplexity(perpl_model: str = '../../trec-pipeline-2021/nlp-improvement
                     n_workers: int = 1,
                     node: int = 1,
                     port: int = 8866):
-    perpl_computer = PerplexityComputer.from_str(perpl_model)
+    perpl_computer = PerplexityComputer.from_str(model)
     content_processor = PerplexityProcessor(perpl_computer, perpl_limit)
     processor = DatasetProcessor(base_dir=base_dir, output_dir=output_dir, content_processor=content_processor)
     execute_processor(base_dir, distributed, n_workers, node, port, processor, warc_input)
@@ -52,8 +52,8 @@ def bulk_perplexity(perpl_model: str = '../../trec-pipeline-2021/nlp-improvement
 
 @app.command()
 def perplexity(text: str,
-               perpl_model: str = '../../trec-pipeline-2021/nlp-improvements/perplexity/models/bigrams_cord19.st'):
-    perpl_computer = PerplexityComputer.from_str(perpl_model)
+               model: str = 'bigrams-bnc'):
+    perpl_computer = PerplexityComputer.from_str(model)
     typer.echo(perpl_computer.compute_sentence(text))
 
 
